<?php
namespace Dominie;

/**
 * Class Plugin
 * Main Plugin class
 * @since 1.2.0
 */
class Plugin {

	/**
	 * Instance
	 *
	 * @since 1.2.0
	 * @access private
	 * @static
	 *
	 * @var Plugin The single instance of the class.
	 */
	private static $_instance = null;

	/**
	 * Instance
	 *
	 * Ensures only one instance of the class is loaded or can be loaded.
	 *
	 * @since 1.2.0
	 * @access public
	 *
	 * @return Plugin An instance of the class.
	 */
	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	/**
		 * _widget_categories()
		 * @since 1.0.0
		 * */
		public function _widget_categories($elements_manager){
			$elements_manager->add_category(
				'dominie_widgets',
				[
					'title' => __( 'Dominie Widgets', 'dominie' ),
					'icon' => 'fa fa-plug',
				]
			);
		}

	/**
	 * widget_scripts
	 *
	 * Load required plugin core files.
	 *
	 * @since 1.2.0
	 * @access public
	 */
	public function widget_scripts() {
		wp_register_script( 'dominie', plugins_url( '/assets/js/hello-world.js', __FILE__ ), [ 'jquery' ], false, true );
	}

	/**
	 * Include Widgets files
	 *
	 * Load widgets files
	 *
	 * @since 1.2.0
	 * @access private
	 */
	private function include_widgets_files() {
		require_once( __DIR__ . '/widgets/dmne-section-title.php' );
		require_once( __DIR__ . '/widgets/dmne-banner.php' );
		require_once( __DIR__ . '/widgets/dmne-client.php' );
		require_once( __DIR__ . '/widgets/dmne-blog.php' );
		require_once( __DIR__ . '/widgets/dmne-testimonial.php' );
		require_once( __DIR__ . '/widgets/dmne-intro.php' );
		require_once( __DIR__ . '/widgets/dmne-course.php' );
		require_once( __DIR__ . '/widgets/dmne-category.php' );
		require_once( __DIR__ . '/widgets/dmne-slider.php' );
		require_once( __DIR__ . '/widgets/dmne-instructor.php' );
	}

	/**
	 * Register Widgets
	 *
	 * Register new Elementor widgets.
	 *
	 * @since 1.2.0
	 * @access public
	 */
	public function register_widgets() {
		// Its is now safe to include Widgets files
		$this->include_widgets_files();

		// Register Widgets
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Dmne_Section_Title() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Dmne_Banner() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Dmne_Client() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Dmne_Blog() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Dmne_Testimonial() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Dmne_Intro() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Dmne_Course() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Dmne_Category() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Dmne_Slider() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Dmne_Instructor() );
	}

	/**
	 *  Plugin class constructor
	 *
	 * Register plugin action hooks and filters
	 *
	 * @since 1.2.0
	 * @access public
	 */
	public function __construct() {
		add_action( 'elementor/elements/categories_registered', array($this,'_widget_categories') );

		// Register widget scripts
		add_action( 'elementor/frontend/after_register_scripts', [ $this, 'widget_scripts' ] );

		// Register widgets
		add_action( 'elementor/widgets/widgets_registered', [ $this, 'register_widgets' ] );
	}
}

// Instantiate Plugin Class
Plugin::instance();
